@@ -25,10 +25,15 @@ extern GSList *ignores;
 
 int ignore_check(SERVER_REC *server, const char *nick, const char *host,
 		 const char *channel, const char *text, int level);
+int ignore_check_flags(SERVER_REC *server, const char *nick, const char *host,
+		       const char *channel, const char *text, int level, int flags);
+int ignore_check_plus(SERVER_REC *server, const char *nick, const char *host,
+		      const char *channel, const char *text, int *level, int test_ignore);
 
 enum {
 	IGNORE_FIND_PATTERN = 0x01, /* Match the pattern */
 	IGNORE_FIND_NOACT   = 0x02, /* Exclude the targets with NOACT level */
+	IGNORE_FIND_HIDDEN  = 0x04, /* Exclude the targets with HIDDEN level */
 };
 
 IGNORE_REC *ignore_find_full (const char *servertag, const char *mask, const char *pattern,
@@ -38,6 +43,7 @@ IGNORE_REC *ignore_find_full (const char *servertag, const char *mask, const cha
 
 IGNORE_REC *ignore_find(const char *servertag, const char *mask, char **channels);
 IGNORE_REC *ignore_find_noact(const char *servertag, const char *mask, char **channels, int noact);
+IGNORE_REC *ignore_find_hidden(const char *servertag, const char *mask, char **channels, int hidden);
 
 void ignore_add_rec(IGNORE_REC *rec);
 void ignore_update_rec(IGNORE_REC *rec);
